@@ -15,21 +15,6 @@ from inforion.excelexport import *
 from inforion.helper.filehandling import *
 from inforion.ionapi.controller import *
 from inforion.ionapi.model import *
-import inforion.ln as lni
-
-import logging
-import os.path
-import os
-
-import logging
-#from logger import get_logger
-
-from inforion.datacatalog.datacatalog import (
-    post_datacatalog_object,
-    delete_datacatalog_object,
-    ObjectSchemaType,
-)
-from inforion.messaging.messaging import post_messaging_v2_multipart_message
 from inforion.ionapi.model import inforlogin
 from inforion.messaging.messaging import post_messaging_v2_multipart_message
 
@@ -127,7 +112,7 @@ def load(
                 inputfile = config_json["inputfile"]
                 outputfile = config_json["outputfile"]
             else:
-                logging.error("JSON File wrong config")
+                print("JSON File wrong config")
                 sys.exit(0)
             if "start" in config_json:
                 start = config_json["start"]
@@ -154,9 +139,9 @@ def load(
 def extract(program, outputfile):
 
     if not "program" in locals() or not program:
-        logging.info("\033[91m" + "Error: Program name is missing" + "\033[0m")
+        print("\033[91m" + "Error: Program name is missing" + "\033[0m")
     if not "outputfile" in locals() or not outputfile:
-        logging.info("\033[91m" + "Error: Output filename is missing" + "\033[0m")
+        print("\033[91m" + "Error: Output filename is missing" + "\033[0m")
 
     if program and outputfile:
         generate_api_template_file(program, outputfile)
@@ -338,6 +323,7 @@ def datalake_get(ionfile, stream_id):
         logger.error(response.content)
 
 
+
 @main.group(name="check")
 def check():
     """Commands to check soemthing"""
@@ -347,31 +333,12 @@ def check():
 @check.command(name="Check_Token", help="Check Login Token")
 @click.option("--url", "-u", help="URL to local ION")
 @click.option("--ionfile", "-i", help="Please define the ionfile file")
-def check_token(url, ionfile):
+
+def check_token(url,ionfile):
     """Check Login and display the token"""
     inforlogin.load_config(ionfile)
     inforlogin.login()
 
-
-@main.group(name="ln")
-def ln():
-    """Commands related to Export Data from LN."""
-    pass
-
-
-@ln.command(name="ExportData", help="Export Data")
-@click.option("--url", "-u", help="URL to local ION")
-@click.option("--ionfile", "-i", help="Please define the ionfile file")
-@click.option("--company", "-c", help="Company for which we need to export")
-@click.option("--service_name", "-s", help="Service name. e.g. BusinessPartner, SalesOrder")
-@click.option("--outputfile", "-o", help="File as Output File")
-def export_data(url, ionfile, company, service_name, outputfile):
-    """Exports business partner to an Excel file"""
-
-    inforlogin.load_config(ionfile)
-    token = inforlogin.login()['access_token']
-    lni.export_data(url, token, company, service_name, outputfile)
-
 main.add_command(load)
 main.add_command(transform)
 main.add_command(extract)
